Class: Google::Apis::VmmigrationV1::CutoverJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

CutoverJob message describes a cutover of a migrating VM. The CutoverJob is the operation of shutting down the VM, creating a snapshot and cloning the VM using the replicated snapshot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CutoverJob

Returns a new instance of CutoverJob.



1752
1753
1754
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compute_engine_disks_target_detailsGoogle::Apis::VmmigrationV1::ComputeEngineDisksTargetDetails

ComputeEngineDisksTargetDetails is a collection of created Persistent Disks details. Corresponds to the JSON property computeEngineDisksTargetDetails



1692
1693
1694
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1692

def compute_engine_disks_target_details
  @compute_engine_disks_target_details
end

#compute_engine_target_detailsGoogle::Apis::VmmigrationV1::ComputeEngineTargetDetails

ComputeEngineTargetDetails is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property computeEngineTargetDetails



1698
1699
1700
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1698

def compute_engine_target_details
  @compute_engine_target_details
end

#create_timeString

Output only. The time the cutover job was created (as an API call, not when it was actually created in the target). Corresponds to the JSON property createTime

Returns:

  • (String)


1704
1705
1706
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1704

def create_time
  @create_time
end

#end_timeString

Output only. The time the cutover job had finished. Corresponds to the JSON property endTime

Returns:

  • (String)


1709
1710
1711
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1709

def end_time
  @end_time
end

#errorGoogle::Apis::VmmigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1719
1720
1721
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1719

def error
  @error
end

#nameString

Output only. The name of the cutover job. Corresponds to the JSON property name

Returns:

  • (String)


1724
1725
1726
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1724

def name
  @name
end

#progress_percentFixnum

Output only. The current progress in percentage of the cutover job. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


1729
1730
1731
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1729

def progress_percent
  @progress_percent
end

#stateString

Output only. State of the cutover job. Corresponds to the JSON property state

Returns:

  • (String)


1734
1735
1736
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1734

def state
  @state
end

#state_messageString

Output only. A message providing possible extra details about the current state. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1740

def state_message
  @state_message
end

#state_timeString

Output only. The time the state was last updated. Corresponds to the JSON property stateTime

Returns:

  • (String)


1745
1746
1747
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1745

def state_time
  @state_time
end

#stepsArray<Google::Apis::VmmigrationV1::CutoverStep>

Output only. The cutover steps list representing its progress. Corresponds to the JSON property steps



1750
1751
1752
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1750

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1757

def update!(**args)
  @compute_engine_disks_target_details = args[:compute_engine_disks_target_details] if args.key?(:compute_engine_disks_target_details)
  @compute_engine_target_details = args[:compute_engine_target_details] if args.key?(:compute_engine_target_details)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @state_time = args[:state_time] if args.key?(:state_time)
  @steps = args[:steps] if args.key?(:steps)
end