Class: Google::Apis::VmmigrationV1::DataDiskImageImport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

Used when the image import is not using OS adaptation process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataDiskImageImport

Returns a new instance of DataDiskImageImport.



1887
1888
1889
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guest_os_featuresArray<String>

Optional. A list of guest OS features to apply to the imported image. These features are flags that are used by Compute Engine to enable certain capabilities for virtual machine instances that are created from the image. This field does not change the OS of the image; it only marks the image with the specified features. The user must ensure that the OS is compatible with the features. For a list of available features, see https://cloud.google.com/ compute/docs/images/create-custom#guest-os-features. Corresponds to the JSON property guestOsFeatures

Returns:

  • (Array<String>)


1885
1886
1887
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1885

def guest_os_features
  @guest_os_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1892
1893
1894
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 1892

def update!(**args)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
end