Class: Google::Apis::VmmigrationV1::DiskImageTargetDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

The target details of the image resource that will be created by the import job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskImageTargetDetails

Returns a new instance of DiskImageTargetDetails.



2122
2123
2124
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_licensesArray<String>

Optional. Additional licenses to assign to the image. Format: https://www. googleapis.com/compute/v1/projects/PROJECT_ID/global/licenses/LICENSE_NAME Or https://www.googleapis.com/compute/beta/projects/PROJECT_ID/global/licenses/ LICENSE_NAME Corresponds to the JSON property additionalLicenses

Returns:

  • (Array<String>)


2072
2073
2074
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2072

def additional_licenses
  @additional_licenses
end

#data_disk_image_importGoogle::Apis::VmmigrationV1::DataDiskImageImport

Used when the image import is not using OS adaptation process. Corresponds to the JSON property dataDiskImageImport



2077
2078
2079
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2077

def data_disk_image_import
  @data_disk_image_import
end

#descriptionString

Optional. An optional description of the image. Corresponds to the JSON property description

Returns:

  • (String)


2082
2083
2084
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2082

def description
  @description
end

#encryptionGoogle::Apis::VmmigrationV1::Encryption

Encryption message describes the details of the applied encryption. Corresponds to the JSON property encryption



2087
2088
2089
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2087

def encryption
  @encryption
end

#family_nameString

Optional. The name of the image family to which the new image belongs. Corresponds to the JSON property familyName

Returns:

  • (String)


2092
2093
2094
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2092

def family_name
  @family_name
end

#image_nameString

Required. The name of the image to be created. Corresponds to the JSON property imageName

Returns:

  • (String)


2097
2098
2099
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2097

def image_name
  @image_name
end

#labelsHash<String,String>

Optional. A map of labels to associate with the image. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2102
2103
2104
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2102

def labels
  @labels
end

#os_adaptation_parametersGoogle::Apis::VmmigrationV1::ImageImportOsAdaptationParameters

Parameters affecting the OS adaptation process. Corresponds to the JSON property osAdaptationParameters



2107
2108
2109
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2107

def os_adaptation_parameters
  @os_adaptation_parameters
end

#single_region_storageBoolean Also known as: single_region_storage?

Optional. Set to true to set the image storageLocations to the single region of the import job. When false, the closest multi-region is selected. Corresponds to the JSON property singleRegionStorage

Returns:

  • (Boolean)


2113
2114
2115
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2113

def single_region_storage
  @single_region_storage
end

#target_projectString

Required. Reference to the TargetProject resource that represents the target project in which the imported image will be created. Corresponds to the JSON property targetProject

Returns:

  • (String)


2120
2121
2122
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2120

def target_project
  @target_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2127

def update!(**args)
  @additional_licenses = args[:additional_licenses] if args.key?(:additional_licenses)
  @data_disk_image_import = args[:data_disk_image_import] if args.key?(:data_disk_image_import)
  @description = args[:description] if args.key?(:description)
  @encryption = args[:encryption] if args.key?(:encryption)
  @family_name = args[:family_name] if args.key?(:family_name)
  @image_name = args[:image_name] if args.key?(:image_name)
  @labels = args[:labels] if args.key?(:labels)
  @os_adaptation_parameters = args[:os_adaptation_parameters] if args.key?(:os_adaptation_parameters)
  @single_region_storage = args[:single_region_storage] if args.key?(:single_region_storage)
  @target_project = args[:target_project] if args.key?(:target_project)
end