Class: Google::Apis::VmmigrationV1::ImageImport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

ImageImport describes the configuration of the image import to run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageImport

Returns a new instance of ImageImport.



2710
2711
2712
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_storage_uriString

Immutable. The path to the Cloud Storage file from which the image should be imported. Corresponds to the JSON property cloudStorageUri

Returns:

  • (String)


2675
2676
2677
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2675

def cloud_storage_uri
  @cloud_storage_uri
end

#create_timeString

Output only. The time the image import was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2680
2681
2682
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2680

def create_time
  @create_time
end

#disk_image_target_defaultsGoogle::Apis::VmmigrationV1::DiskImageTargetDetails

The target details of the image resource that will be created by the import job. Corresponds to the JSON property diskImageTargetDefaults



2686
2687
2688
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2686

def disk_image_target_defaults
  @disk_image_target_defaults
end

#encryptionGoogle::Apis::VmmigrationV1::Encryption

Encryption message describes the details of the applied encryption. Corresponds to the JSON property encryption



2691
2692
2693
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2691

def encryption
  @encryption
end

#machine_image_target_defaultsGoogle::Apis::VmmigrationV1::MachineImageTargetDetails

The target details of the machine image resource that will be created by the image import job. Corresponds to the JSON property machineImageTargetDefaults



2697
2698
2699
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2697

def machine_image_target_defaults
  @machine_image_target_defaults
end

#nameString

Output only. The resource path of the ImageImport. Corresponds to the JSON property name

Returns:

  • (String)


2702
2703
2704
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2702

def name
  @name
end

#recent_image_import_jobsArray<Google::Apis::VmmigrationV1::ImageImportJob>

Output only. The result of the most recent runs for this ImageImport. All jobs for this ImageImport can be listed via ListImageImportJobs. Corresponds to the JSON property recentImageImportJobs



2708
2709
2710
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2708

def recent_image_import_jobs
  @recent_image_import_jobs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2715
2716
2717
2718
2719
2720
2721
2722
2723
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2715

def update!(**args)
  @cloud_storage_uri = args[:cloud_storage_uri] if args.key?(:cloud_storage_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @disk_image_target_defaults = args[:disk_image_target_defaults] if args.key?(:disk_image_target_defaults)
  @encryption = args[:encryption] if args.key?(:encryption)
  @machine_image_target_defaults = args[:machine_image_target_defaults] if args.key?(:machine_image_target_defaults)
  @name = args[:name] if args.key?(:name)
  @recent_image_import_jobs = args[:recent_image_import_jobs] if args.key?(:recent_image_import_jobs)
end