Class: Google::Apis::VmmigrationV1::ImageImportJob
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::ImageImportJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
ImageImportJob describes the progress and result of an image import.
Instance Attribute Summary collapse
-
#cloud_storage_uri ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#created_resources ⇒ Array<String>
Output only.
-
#disk_image_target_details ⇒ Google::Apis::VmmigrationV1::DiskImageTargetDetails
The target details of the image resource that will be created by the import job.
-
#end_time ⇒ String
Output only.
-
#errors ⇒ Array<Google::Apis::VmmigrationV1::Status>
Output only.
-
#machine_image_target_details ⇒ Google::Apis::VmmigrationV1::MachineImageTargetDetails
The target details of the machine image resource that will be created by the image import job.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#steps ⇒ Array<Google::Apis::VmmigrationV1::ImageImportStep>
Output only.
-
#warnings ⇒ Array<Google::Apis::VmmigrationV1::MigrationWarning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageImportJob
constructor
A new instance of ImageImportJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageImportJob
Returns a new instance of ImageImportJob.
2791 2792 2793 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_storage_uri ⇒ String
Output only. The path to the Cloud Storage file from which the image should be
imported.
Corresponds to the JSON property cloudStorageUri
2734 2735 2736 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2734 def cloud_storage_uri @cloud_storage_uri end |
#create_time ⇒ String
Output only. The time the image import was created (as an API call, not when
it was actually created in the target).
Corresponds to the JSON property createTime
2740 2741 2742 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2740 def create_time @create_time end |
#created_resources ⇒ Array<String>
Output only. The resource paths of the resources created by the image import
job.
Corresponds to the JSON property createdResources
2746 2747 2748 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2746 def created_resources @created_resources end |
#disk_image_target_details ⇒ Google::Apis::VmmigrationV1::DiskImageTargetDetails
The target details of the image resource that will be created by the import
job.
Corresponds to the JSON property diskImageTargetDetails
2752 2753 2754 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2752 def disk_image_target_details @disk_image_target_details end |
#end_time ⇒ String
Output only. The time the image import was ended.
Corresponds to the JSON property endTime
2757 2758 2759 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2757 def end_time @end_time end |
#errors ⇒ Array<Google::Apis::VmmigrationV1::Status>
Output only. Provides details on the error that led to the image import state
in case of an error.
Corresponds to the JSON property errors
2763 2764 2765 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2763 def errors @errors end |
#machine_image_target_details ⇒ Google::Apis::VmmigrationV1::MachineImageTargetDetails
The target details of the machine image resource that will be created by the
image import job.
Corresponds to the JSON property machineImageTargetDetails
2769 2770 2771 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2769 def machine_image_target_details @machine_image_target_details end |
#name ⇒ String
Output only. The resource path of the ImageImportJob.
Corresponds to the JSON property name
2774 2775 2776 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2774 def name @name end |
#state ⇒ String
Output only. The state of the image import.
Corresponds to the JSON property state
2779 2780 2781 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2779 def state @state end |
#steps ⇒ Array<Google::Apis::VmmigrationV1::ImageImportStep>
Output only. The image import steps list representing its progress.
Corresponds to the JSON property steps
2784 2785 2786 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2784 def steps @steps end |
#warnings ⇒ Array<Google::Apis::VmmigrationV1::MigrationWarning>
Output only. Warnings that occurred during the image import.
Corresponds to the JSON property warnings
2789 2790 2791 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2789 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2796 def update!(**args) @cloud_storage_uri = args[:cloud_storage_uri] if args.key?(:cloud_storage_uri) @create_time = args[:create_time] if args.key?(:create_time) @created_resources = args[:created_resources] if args.key?(:created_resources) @disk_image_target_details = args[:disk_image_target_details] if args.key?(:disk_image_target_details) @end_time = args[:end_time] if args.key?(:end_time) @errors = args[:errors] if args.key?(:errors) @machine_image_target_details = args[:machine_image_target_details] if args.key?(:machine_image_target_details) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @steps = args[:steps] if args.key?(:steps) @warnings = args[:warnings] if args.key?(:warnings) end |