Class: Google::Apis::VmmigrationV1::ImageImportOsAdaptationParameters
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::ImageImportOsAdaptationParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
Parameters affecting the OS adaptation process.
Instance Attribute Summary collapse
-
#adaptation_modifiers ⇒ Array<Google::Apis::VmmigrationV1::AdaptationModifier>
Optional.
-
#boot_conversion ⇒ String
Optional.
-
#generalize ⇒ Boolean
(also: #generalize?)
Optional.
-
#license_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageImportOsAdaptationParameters
constructor
A new instance of ImageImportOsAdaptationParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageImportOsAdaptationParameters
Returns a new instance of ImageImportOsAdaptationParameters.
2843 2844 2845 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation_modifiers ⇒ Array<Google::Apis::VmmigrationV1::AdaptationModifier>
Optional. Modifiers to be used as configuration of the OS adaptation process.
Corresponds to the JSON property adaptationModifiers
2818 2819 2820 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2818 def adaptation_modifiers @adaptation_modifiers end |
#boot_conversion ⇒ String
Optional. By default the image will keep its existing boot option. Setting
this property will trigger an internal process which will convert the image
from using the existing boot option to another. The size of the boot disk
might be increased to allow the conversion
Corresponds to the JSON property bootConversion
2826 2827 2828 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2826 def boot_conversion @boot_conversion end |
#generalize ⇒ Boolean Also known as: generalize?
Optional. Set to true in order to generalize the imported image. The
generalization process enables co-existence of multiple VMs created from the
same image. For Windows, generalizing the image removes computer-specific
information such as installed drivers and the computer security identifier (
SID).
Corresponds to the JSON property generalize
2835 2836 2837 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2835 def generalize @generalize end |
#license_type ⇒ String
Optional. Choose which type of license to apply to the imported image.
Corresponds to the JSON property licenseType
2841 2842 2843 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2841 def license_type @license_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2848 2849 2850 2851 2852 2853 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2848 def update!(**args) @adaptation_modifiers = args[:adaptation_modifiers] if args.key?(:adaptation_modifiers) @boot_conversion = args[:boot_conversion] if args.key?(:boot_conversion) @generalize = args[:generalize] if args.key?(:generalize) @license_type = args[:license_type] if args.key?(:license_type) end |