Class: Google::Apis::VmmigrationV1::MigrationWarning

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

Represents migration resource warning information that can be used with google. rpc.Status message. MigrationWarning is used to present the user with warning information in migration operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationWarning

Returns a new instance of MigrationWarning.



3888
3889
3890
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_itemGoogle::Apis::VmmigrationV1::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property actionItem



3864
3865
3866
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3864

def action_item
  @action_item
end

#codeString

The warning code. Corresponds to the JSON property code

Returns:

  • (String)


3869
3870
3871
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3869

def code
  @code
end

Output only. URL(s) pointing to additional information on handling the current warning. Corresponds to the JSON property helpLinks



3875
3876
3877
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3875

def help_links
  @help_links
end

#warning_messageGoogle::Apis::VmmigrationV1::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property warningMessage



3881
3882
3883
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3881

def warning_message
  @warning_message
end

#warning_timeString

The time the warning occurred. Corresponds to the JSON property warningTime

Returns:

  • (String)


3886
3887
3888
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3886

def warning_time
  @warning_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3893
3894
3895
3896
3897
3898
3899
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3893

def update!(**args)
  @action_item = args[:action_item] if args.key?(:action_item)
  @code = args[:code] if args.key?(:code)
  @help_links = args[:help_links] if args.key?(:help_links)
  @warning_message = args[:warning_message] if args.key?(:warning_message)
  @warning_time = args[:warning_time] if args.key?(:warning_time)
end