Class: Google::Apis::VmmigrationV1::PersistentDiskDefaults
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::PersistentDiskDefaults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
Details for creation of a Persistent Disk.
Instance Attribute Summary collapse
-
#additional_labels ⇒ Hash<String,String>
A map of labels to associate with the Persistent Disk.
-
#disk_name ⇒ String
Optional.
-
#disk_type ⇒ String
The disk type to use.
-
#encryption ⇒ Google::Apis::VmmigrationV1::Encryption
Encryption message describes the details of the applied encryption.
-
#source_disk_number ⇒ Fixnum
Required.
-
#vm_attachment_details ⇒ Google::Apis::VmmigrationV1::VmAttachmentDetails
Details for attachment of the disk to a VM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PersistentDiskDefaults
constructor
A new instance of PersistentDiskDefaults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PersistentDiskDefaults
Returns a new instance of PersistentDiskDefaults.
4204 4205 4206 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_labels ⇒ Hash<String,String>
A map of labels to associate with the Persistent Disk.
Corresponds to the JSON property additionalLabels
4177 4178 4179 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4177 def additional_labels @additional_labels end |
#disk_name ⇒ String
Optional. The name of the Persistent Disk to create.
Corresponds to the JSON property diskName
4182 4183 4184 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4182 def disk_name @disk_name end |
#disk_type ⇒ String
The disk type to use.
Corresponds to the JSON property diskType
4187 4188 4189 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4187 def disk_type @disk_type end |
#encryption ⇒ Google::Apis::VmmigrationV1::Encryption
Encryption message describes the details of the applied encryption.
Corresponds to the JSON property encryption
4192 4193 4194 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4192 def encryption @encryption end |
#source_disk_number ⇒ Fixnum
Required. The ordinal number of the source VM disk.
Corresponds to the JSON property sourceDiskNumber
4197 4198 4199 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4197 def source_disk_number @source_disk_number end |
#vm_attachment_details ⇒ Google::Apis::VmmigrationV1::VmAttachmentDetails
Details for attachment of the disk to a VM.
Corresponds to the JSON property vmAttachmentDetails
4202 4203 4204 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4202 def @vm_attachment_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4209 def update!(**args) @additional_labels = args[:additional_labels] if args.key?(:additional_labels) @disk_name = args[:disk_name] if args.key?(:disk_name) @disk_type = args[:disk_type] if args.key?(:disk_type) @encryption = args[:encryption] if args.key?(:encryption) @source_disk_number = args[:source_disk_number] if args.key?(:source_disk_number) @vm_attachment_details = args[:vm_attachment_details] if args.key?(:vm_attachment_details) end |