Class: Google::Apis::VmmigrationV1::ReplicatingStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

ReplicatingStep contains specific step details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicatingStep

Returns a new instance of ReplicatingStep.



4301
4302
4303
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_thirty_minutes_average_bytes_per_secondFixnum

The source disks replication rate for the last 30 minutes in bytes per second. Corresponds to the JSON property lastThirtyMinutesAverageBytesPerSecond

Returns:

  • (Fixnum)


4284
4285
4286
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4284

def last_thirty_minutes_average_bytes_per_second
  @last_thirty_minutes_average_bytes_per_second
end

#last_two_minutes_average_bytes_per_secondFixnum

The source disks replication rate for the last 2 minutes in bytes per second. Corresponds to the JSON property lastTwoMinutesAverageBytesPerSecond

Returns:

  • (Fixnum)


4289
4290
4291
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4289

def last_two_minutes_average_bytes_per_second
  @last_two_minutes_average_bytes_per_second
end

#replicated_bytesFixnum

Replicated bytes in the step. Corresponds to the JSON property replicatedBytes

Returns:

  • (Fixnum)


4294
4295
4296
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4294

def replicated_bytes
  @replicated_bytes
end

#total_bytesFixnum

Total bytes to be handled in the step. Corresponds to the JSON property totalBytes

Returns:

  • (Fixnum)


4299
4300
4301
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4299

def total_bytes
  @total_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4306
4307
4308
4309
4310
4311
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4306

def update!(**args)
  @last_thirty_minutes_average_bytes_per_second = args[:last_thirty_minutes_average_bytes_per_second] if args.key?(:last_thirty_minutes_average_bytes_per_second)
  @last_two_minutes_average_bytes_per_second = args[:last_two_minutes_average_bytes_per_second] if args.key?(:last_two_minutes_average_bytes_per_second)
  @replicated_bytes = args[:replicated_bytes] if args.key?(:replicated_bytes)
  @total_bytes = args[:total_bytes] if args.key?(:total_bytes)
end