Class: Google::Apis::VmmigrationV1::ShieldedInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

Shielded instance configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShieldedInstanceConfig

Returns a new instance of ShieldedInstanceConfig.



4550
4551
4552
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_integrity_monitoringBoolean Also known as: enable_integrity_monitoring?

Optional. Defines whether the instance created by the machine image has integrity monitoring enabled. This can be set to true only if the image boot option is EFI, and vTPM is enabled. Corresponds to the JSON property enableIntegrityMonitoring

Returns:

  • (Boolean)


4534
4535
4536
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4534

def enable_integrity_monitoring
  @enable_integrity_monitoring
end

#enable_vtpmBoolean Also known as: enable_vtpm?

Optional. Defines whether the instance created by the machine image has vTPM enabled. This can be set to true only if the image boot option is EFI. Corresponds to the JSON property enableVtpm

Returns:

  • (Boolean)


4541
4542
4543
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4541

def enable_vtpm
  @enable_vtpm
end

#secure_bootString

Optional. Defines whether the instance created by the machine image has Secure Boot enabled. This can be set to true only if the image boot option is EFI. Corresponds to the JSON property secureBoot

Returns:

  • (String)


4548
4549
4550
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4548

def secure_boot
  @secure_boot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4555
4556
4557
4558
4559
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4555

def update!(**args)
  @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring)
  @enable_vtpm = args[:enable_vtpm] if args.key?(:enable_vtpm)
  @secure_boot = args[:secure_boot] if args.key?(:secure_boot)
end