Class: Google::Apis::VmmigrationV1::Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

Source message describes a specific vm migration Source resource. It contains the source environment information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



4647
4648
4649
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#awsGoogle::Apis::VmmigrationV1::AwsSourceDetails

AwsSourceDetails message describes a specific source details for the AWS source type. Corresponds to the JSON property aws



4603
4604
4605
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4603

def aws
  @aws
end

#azureGoogle::Apis::VmmigrationV1::AzureSourceDetails

AzureSourceDetails message describes a specific source details for the Azure source type. Corresponds to the JSON property azure



4609
4610
4611
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4609

def azure
  @azure
end

#create_timeString

Output only. The create time timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4614
4615
4616
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4614

def create_time
  @create_time
end

#descriptionString

User-provided description of the source. Corresponds to the JSON property description

Returns:

  • (String)


4619
4620
4621
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4619

def description
  @description
end

#encryptionGoogle::Apis::VmmigrationV1::Encryption

Encryption message describes the details of the applied encryption. Corresponds to the JSON property encryption



4624
4625
4626
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4624

def encryption
  @encryption
end

#labelsHash<String,String>

The labels of the source. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4629
4630
4631
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4629

def labels
  @labels
end

#nameString

Output only. The Source name. Corresponds to the JSON property name

Returns:

  • (String)


4634
4635
4636
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4634

def name
  @name
end

#update_timeString

Output only. The update time timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4639

def update_time
  @update_time
end

#vmwareGoogle::Apis::VmmigrationV1::VmwareSourceDetails

VmwareSourceDetails message describes a specific source details for the vmware source type. Corresponds to the JSON property vmware



4645
4646
4647
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4645

def vmware
  @vmware
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
4662
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4652

def update!(**args)
  @aws = args[:aws] if args.key?(:aws)
  @azure = args[:azure] if args.key?(:azure)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @encryption = args[:encryption] if args.key?(:encryption)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware = args[:vmware] if args.key?(:vmware)
end