Class: Google::Apis::VmmigrationV1::UpgradeStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

UpgradeStatus contains information about upgradeAppliance operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeStatus

Returns a new instance of UpgradeStatus.



4868
4869
4870
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::VmmigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4846
4847
4848
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4846

def error
  @error
end

#previous_versionString

The version from which we upgraded. Corresponds to the JSON property previousVersion

Returns:

  • (String)


4851
4852
4853
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4851

def previous_version
  @previous_version
end

#start_timeString

The time the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


4856
4857
4858
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4856

def start_time
  @start_time
end

#stateString

The state of the upgradeAppliance operation. Corresponds to the JSON property state

Returns:

  • (String)


4861
4862
4863
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4861

def state
  @state
end

#versionString

The version to upgrade to. Corresponds to the JSON property version

Returns:

  • (String)


4866
4867
4868
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4866

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4873
4874
4875
4876
4877
4878
4879
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4873

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @previous_version = args[:previous_version] if args.key?(:previous_version)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end