Class: Google::Apis::VmmigrationV1::VmwareSourceDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

VmwareSourceDetails message describes a specific source details for the vmware source type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmwareSourceDetails

Returns a new instance of VmwareSourceDetails.



5168
5169
5170
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#passwordString

Input only. The credentials password. This is write only and can not be read in a GET operation. Corresponds to the JSON property password

Returns:

  • (String)


5146
5147
5148
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5146

def password
  @password
end

#resolved_vcenter_hostString

The hostname of the vcenter. Corresponds to the JSON property resolvedVcenterHost

Returns:

  • (String)


5151
5152
5153
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5151

def resolved_vcenter_host
  @resolved_vcenter_host
end

#thumbprintString

The thumbprint representing the certificate for the vcenter. Corresponds to the JSON property thumbprint

Returns:

  • (String)


5156
5157
5158
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5156

def thumbprint
  @thumbprint
end

#usernameString

The credentials username. Corresponds to the JSON property username

Returns:

  • (String)


5161
5162
5163
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5161

def username
  @username
end

#vcenter_ipString

The ip address of the vcenter this Source represents. Corresponds to the JSON property vcenterIp

Returns:

  • (String)


5166
5167
5168
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5166

def vcenter_ip
  @vcenter_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5173
5174
5175
5176
5177
5178
5179
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5173

def update!(**args)
  @password = args[:password] if args.key?(:password)
  @resolved_vcenter_host = args[:resolved_vcenter_host] if args.key?(:resolved_vcenter_host)
  @thumbprint = args[:thumbprint] if args.key?(:thumbprint)
  @username = args[:username] if args.key?(:username)
  @vcenter_ip = args[:vcenter_ip] if args.key?(:vcenter_ip)
end