Class: Google::Apis::VmmigrationV1::VmwareVmDetails
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::VmwareVmDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
VmwareVmDetails describes a VM in vCenter.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#boot_option ⇒ String
Output only.
-
#committed_storage_mb ⇒ Fixnum
The total size of the storage allocated to the VM in MB.
-
#cpu_count ⇒ Fixnum
The number of cpus in the VM.
-
#datacenter_description ⇒ String
The descriptive name of the vCenter's datacenter this VM is contained in.
-
#datacenter_id ⇒ String
The id of the vCenter's datacenter this VM is contained in.
-
#disk_count ⇒ Fixnum
The number of disks the VM has.
-
#display_name ⇒ String
The display name of the VM.
-
#guest_description ⇒ String
The VM's OS.
-
#memory_mb ⇒ Fixnum
The size of the memory of the VM in MB.
-
#power_state ⇒ String
The power state of the VM at the moment list was taken.
-
#uuid ⇒ String
The unique identifier of the VM in vCenter.
-
#vm_id ⇒ String
The VM's id in the source (note that this is not the MigratingVm's id).
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareVmDetails
constructor
A new instance of VmwareVmDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareVmDetails
Returns a new instance of VmwareVmDetails.
5305 5306 5307 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture.
Corresponds to the JSON property architecture
5239 5240 5241 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5239 def architecture @architecture end |
#boot_option ⇒ String
Output only. The VM Boot Option.
Corresponds to the JSON property bootOption
5244 5245 5246 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5244 def boot_option @boot_option end |
#committed_storage_mb ⇒ Fixnum
The total size of the storage allocated to the VM in MB.
Corresponds to the JSON property committedStorageMb
5249 5250 5251 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5249 def committed_storage_mb @committed_storage_mb end |
#cpu_count ⇒ Fixnum
The number of cpus in the VM.
Corresponds to the JSON property cpuCount
5254 5255 5256 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5254 def cpu_count @cpu_count end |
#datacenter_description ⇒ String
The descriptive name of the vCenter's datacenter this VM is contained in.
Corresponds to the JSON property datacenterDescription
5259 5260 5261 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5259 def datacenter_description @datacenter_description end |
#datacenter_id ⇒ String
The id of the vCenter's datacenter this VM is contained in.
Corresponds to the JSON property datacenterId
5264 5265 5266 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5264 def datacenter_id @datacenter_id end |
#disk_count ⇒ Fixnum
The number of disks the VM has.
Corresponds to the JSON property diskCount
5269 5270 5271 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5269 def disk_count @disk_count end |
#display_name ⇒ String
The display name of the VM. Note that this is not necessarily unique.
Corresponds to the JSON property displayName
5274 5275 5276 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5274 def display_name @display_name end |
#guest_description ⇒ String
The VM's OS. See for example https://vdc-repo.vmware.com/vmwb-repository/dcr-
public/da47f910-60ac-438b-8b9b-6122f4d14524/16b7274a-bf8b-4b4c-a05e-
746f2aa93c8c/doc/vim.vm.GuestOsDescriptor.GuestOsIdentifier.html for types of
strings this might hold.
Corresponds to the JSON property guestDescription
5282 5283 5284 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5282 def guest_description @guest_description end |
#memory_mb ⇒ Fixnum
The size of the memory of the VM in MB.
Corresponds to the JSON property memoryMb
5287 5288 5289 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5287 def memory_mb @memory_mb end |
#power_state ⇒ String
The power state of the VM at the moment list was taken.
Corresponds to the JSON property powerState
5292 5293 5294 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5292 def power_state @power_state end |
#uuid ⇒ String
The unique identifier of the VM in vCenter.
Corresponds to the JSON property uuid
5297 5298 5299 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5297 def uuid @uuid end |
#vm_id ⇒ String
The VM's id in the source (note that this is not the MigratingVm's id). This
is the moref id of the VM.
Corresponds to the JSON property vmId
5303 5304 5305 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5303 def vm_id @vm_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 5323 5324 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 5310 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @boot_option = args[:boot_option] if args.key?(:boot_option) @committed_storage_mb = args[:committed_storage_mb] if args.key?(:committed_storage_mb) @cpu_count = args[:cpu_count] if args.key?(:cpu_count) @datacenter_description = args[:datacenter_description] if args.key?(:datacenter_description) @datacenter_id = args[:datacenter_id] if args.key?(:datacenter_id) @disk_count = args[:disk_count] if args.key?(:disk_count) @display_name = args[:display_name] if args.key?(:display_name) @guest_description = args[:guest_description] if args.key?(:guest_description) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @power_state = args[:power_state] if args.key?(:power_state) @uuid = args[:uuid] if args.key?(:uuid) @vm_id = args[:vm_id] if args.key?(:vm_id) end |