Class: Google::Apis::VmmigrationV1::ImageImportJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

ImageImportJob describes the progress and result of an image import.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageImportJob

Returns a new instance of ImageImportJob.



2785
2786
2787
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_storage_uriString

Output only. The path to the Cloud Storage file from which the image should be imported. Corresponds to the JSON property cloudStorageUri

Returns:

  • (String)


2728
2729
2730
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2728

def cloud_storage_uri
  @cloud_storage_uri
end

#create_timeString

Output only. The time the image import was created (as an API call, not when it was actually created in the target). Corresponds to the JSON property createTime

Returns:

  • (String)


2734
2735
2736
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2734

def create_time
  @create_time
end

#created_resourcesArray<String>

Output only. The resource paths of the resources created by the image import job. Corresponds to the JSON property createdResources

Returns:

  • (Array<String>)


2740
2741
2742
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2740

def created_resources
  @created_resources
end

#disk_image_target_detailsGoogle::Apis::VmmigrationV1::DiskImageTargetDetails

The target details of the image resource that will be created by the import job. Corresponds to the JSON property diskImageTargetDetails



2746
2747
2748
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2746

def disk_image_target_details
  @disk_image_target_details
end

#end_timeString

Output only. The time the image import was ended. Corresponds to the JSON property endTime

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2751

def end_time
  @end_time
end

#errorsArray<Google::Apis::VmmigrationV1::Status>

Output only. Provides details on the error that led to the image import state in case of an error. Corresponds to the JSON property errors



2757
2758
2759
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2757

def errors
  @errors
end

#machine_image_target_detailsGoogle::Apis::VmmigrationV1::MachineImageTargetDetails

The target details of the machine image resource that will be created by the image import job. Corresponds to the JSON property machineImageTargetDetails



2763
2764
2765
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2763

def machine_image_target_details
  @machine_image_target_details
end

#nameString

Output only. The resource path of the ImageImportJob. Corresponds to the JSON property name

Returns:

  • (String)


2768
2769
2770
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2768

def name
  @name
end

#stateString

Output only. The state of the image import. Corresponds to the JSON property state

Returns:

  • (String)


2773
2774
2775
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2773

def state
  @state
end

#stepsArray<Google::Apis::VmmigrationV1::ImageImportStep>

Output only. The image import steps list representing its progress. Corresponds to the JSON property steps



2778
2779
2780
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2778

def steps
  @steps
end

#warningsArray<Google::Apis::VmmigrationV1::MigrationWarning>

Output only. Warnings that occurred during the image import. Corresponds to the JSON property warnings



2783
2784
2785
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2783

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 2790

def update!(**args)
  @cloud_storage_uri = args[:cloud_storage_uri] if args.key?(:cloud_storage_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @created_resources = args[:created_resources] if args.key?(:created_resources)
  @disk_image_target_details = args[:disk_image_target_details] if args.key?(:disk_image_target_details)
  @end_time = args[:end_time] if args.key?(:end_time)
  @errors = args[:errors] if args.key?(:errors)
  @machine_image_target_details = args[:machine_image_target_details] if args.key?(:machine_image_target_details)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
  @warnings = args[:warnings] if args.key?(:warnings)
end