Class: Google::Apis::VmmigrationV1::MachineImageTargetDetails
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::MachineImageTargetDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
The target details of the machine image resource that will be created by the image import job.
Instance Attribute Summary collapse
-
#additional_licenses ⇒ Array<String>
Optional.
-
#description ⇒ String
Optional.
-
#encryption ⇒ Google::Apis::VmmigrationV1::Encryption
Encryption message describes the details of the applied encryption.
-
#labels ⇒ Hash<String,String>
Optional.
-
#machine_image_name ⇒ String
Required.
-
#machine_image_parameters_overrides ⇒ Google::Apis::VmmigrationV1::MachineImageParametersOverrides
Parameters overriding decisions based on the source machine image configurations.
-
#network_interfaces ⇒ Array<Google::Apis::VmmigrationV1::NetworkInterface>
Optional.
-
#os_adaptation_parameters ⇒ Google::Apis::VmmigrationV1::ImageImportOsAdaptationParameters
Parameters affecting the OS adaptation process.
-
#service_account ⇒ Google::Apis::VmmigrationV1::ServiceAccount
Service account to assign to the instance created by the machine image.
-
#shielded_instance_config ⇒ Google::Apis::VmmigrationV1::ShieldedInstanceConfig
Shielded instance configuration.
-
#single_region_storage ⇒ Boolean
(also: #single_region_storage?)
Optional.
-
#skip_os_adaptation ⇒ Google::Apis::VmmigrationV1::SkipOsAdaptation
Mentions that the machine image import is not using OS adaptation process.
-
#tags ⇒ Array<String>
Optional.
-
#target_project ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageTargetDetails
constructor
A new instance of MachineImageTargetDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageTargetDetails
Returns a new instance of MachineImageTargetDetails.
3606 3607 3608 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_licenses ⇒ Array<String>
Optional. Additional licenses to assign to the instance created by the machine
image. Format: https://www.googleapis.com/compute/v1/projects/PROJECT_ID/
global/licenses/LICENSE_NAME Or https://www.googleapis.com/compute/beta/
projects/PROJECT_ID/global/licenses/LICENSE_NAME
Corresponds to the JSON property additionalLicenses
3533 3534 3535 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3533 def additional_licenses @additional_licenses end |
#description ⇒ String
Optional. An optional description of the machine image.
Corresponds to the JSON property description
3538 3539 3540 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3538 def description @description end |
#encryption ⇒ Google::Apis::VmmigrationV1::Encryption
Encryption message describes the details of the applied encryption.
Corresponds to the JSON property encryption
3543 3544 3545 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3543 def encryption @encryption end |
#labels ⇒ Hash<String,String>
Optional. The labels to apply to the instance created by the machine image.
Corresponds to the JSON property labels
3548 3549 3550 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3548 def labels @labels end |
#machine_image_name ⇒ String
Required. The name of the machine image to be created.
Corresponds to the JSON property machineImageName
3553 3554 3555 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3553 def machine_image_name @machine_image_name end |
#machine_image_parameters_overrides ⇒ Google::Apis::VmmigrationV1::MachineImageParametersOverrides
Parameters overriding decisions based on the source machine image
configurations.
Corresponds to the JSON property machineImageParametersOverrides
3559 3560 3561 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3559 def machine_image_parameters_overrides @machine_image_parameters_overrides end |
#network_interfaces ⇒ Array<Google::Apis::VmmigrationV1::NetworkInterface>
Optional. The network interfaces to create with the instance created by the
machine image. Internal and external IP addresses, and network tiers are
ignored for machine image import.
Corresponds to the JSON property networkInterfaces
3566 3567 3568 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3566 def network_interfaces @network_interfaces end |
#os_adaptation_parameters ⇒ Google::Apis::VmmigrationV1::ImageImportOsAdaptationParameters
Parameters affecting the OS adaptation process.
Corresponds to the JSON property osAdaptationParameters
3571 3572 3573 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3571 def os_adaptation_parameters @os_adaptation_parameters end |
#service_account ⇒ Google::Apis::VmmigrationV1::ServiceAccount
Service account to assign to the instance created by the machine image.
Corresponds to the JSON property serviceAccount
3576 3577 3578 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3576 def service_account @service_account end |
#shielded_instance_config ⇒ Google::Apis::VmmigrationV1::ShieldedInstanceConfig
Shielded instance configuration.
Corresponds to the JSON property shieldedInstanceConfig
3581 3582 3583 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3581 def shielded_instance_config @shielded_instance_config end |
#single_region_storage ⇒ Boolean Also known as: single_region_storage?
Optional. Set to true to set the machine image storageLocations to the single
region of the import job. When false, the closest multi-region is selected.
Corresponds to the JSON property singleRegionStorage
3587 3588 3589 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3587 def single_region_storage @single_region_storage end |
#skip_os_adaptation ⇒ Google::Apis::VmmigrationV1::SkipOsAdaptation
Mentions that the machine image import is not using OS adaptation process.
Corresponds to the JSON property skipOsAdaptation
3593 3594 3595 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3593 def skip_os_adaptation @skip_os_adaptation end |
#tags ⇒ Array<String>
Optional. The tags to apply to the instance created by the machine image.
Corresponds to the JSON property tags
3598 3599 3600 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3598 def @tags end |
#target_project ⇒ String
Required. Reference to the TargetProject resource that represents the target
project in which the imported machine image will be created.
Corresponds to the JSON property targetProject
3604 3605 3606 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3604 def target_project @target_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3611 def update!(**args) @additional_licenses = args[:additional_licenses] if args.key?(:additional_licenses) @description = args[:description] if args.key?(:description) @encryption = args[:encryption] if args.key?(:encryption) @labels = args[:labels] if args.key?(:labels) @machine_image_name = args[:machine_image_name] if args.key?(:machine_image_name) @machine_image_parameters_overrides = args[:machine_image_parameters_overrides] if args.key?(:machine_image_parameters_overrides) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @os_adaptation_parameters = args[:os_adaptation_parameters] if args.key?(:os_adaptation_parameters) @service_account = args[:service_account] if args.key?(:service_account) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @single_region_storage = args[:single_region_storage] if args.key?(:single_region_storage) @skip_os_adaptation = args[:skip_os_adaptation] if args.key?(:skip_os_adaptation) @tags = args[:tags] if args.key?(:tags) @target_project = args[:target_project] if args.key?(:target_project) end |