Class: Google::Apis::VmmigrationV1::MigratingVm
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::MigratingVm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
MigratingVm describes the VM that will be migrated from a Source environment and its replication state.
Instance Attribute Summary collapse
-
#aws_source_vm_details ⇒ Google::Apis::VmmigrationV1::AwsSourceVmDetails
Represent the source AWS VM details.
-
#azure_source_vm_details ⇒ Google::Apis::VmmigrationV1::AzureSourceVmDetails
Represent the source Azure VM details.
-
#compute_engine_disks_target_defaults ⇒ Google::Apis::VmmigrationV1::ComputeEngineDisksTargetDefaults
ComputeEngineDisksTargetDefaults is a collection of details for creating Persistent Disks in a target Compute Engine project.
-
#compute_engine_target_defaults ⇒ Google::Apis::VmmigrationV1::ComputeEngineTargetDefaults
ComputeEngineTargetDefaults is a collection of details for creating a VM in a target Compute Engine project.
-
#create_time ⇒ String
Output only.
-
#current_sync_info ⇒ Google::Apis::VmmigrationV1::ReplicationCycle
ReplicationCycle contains information about the current replication cycle status.
-
#cutover_forecast ⇒ Google::Apis::VmmigrationV1::CutoverForecast
CutoverForecast holds information about future CutoverJobs of a MigratingVm.
-
#description ⇒ String
The description attached to the migrating VM by the user.
-
#display_name ⇒ String
The display name attached to the MigratingVm by the user.
-
#error ⇒ Google::Apis::VmmigrationV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#expiration ⇒ Google::Apis::VmmigrationV1::Expiration
Expiration holds information about the expiration of a MigratingVm.
-
#group ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels of the migrating VM.
-
#last_replication_cycle ⇒ Google::Apis::VmmigrationV1::ReplicationCycle
ReplicationCycle contains information about the current replication cycle status.
-
#last_sync ⇒ Google::Apis::VmmigrationV1::ReplicationSync
ReplicationSync contain information about the last replica sync to the cloud.
-
#name ⇒ String
Output only.
-
#policy ⇒ Google::Apis::VmmigrationV1::SchedulePolicy
A policy for scheduling replications.
-
#recent_clone_jobs ⇒ Array<Google::Apis::VmmigrationV1::CloneJob>
Output only.
-
#recent_cutover_jobs ⇒ Array<Google::Apis::VmmigrationV1::CutoverJob>
Output only.
-
#source_vm_id ⇒ String
The unique ID of the VM in the source.
-
#state ⇒ String
Output only.
-
#state_time ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vmware_source_vm_details ⇒ Google::Apis::VmmigrationV1::VmwareSourceVmDetails
Represent the source Vmware VM details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigratingVm
constructor
A new instance of MigratingVm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigratingVm
Returns a new instance of MigratingVm.
3767 3768 3769 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aws_source_vm_details ⇒ Google::Apis::VmmigrationV1::AwsSourceVmDetails
Represent the source AWS VM details.
Corresponds to the JSON property awsSourceVmDetails
3631 3632 3633 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3631 def aws_source_vm_details @aws_source_vm_details end |
#azure_source_vm_details ⇒ Google::Apis::VmmigrationV1::AzureSourceVmDetails
Represent the source Azure VM details.
Corresponds to the JSON property azureSourceVmDetails
3636 3637 3638 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3636 def azure_source_vm_details @azure_source_vm_details end |
#compute_engine_disks_target_defaults ⇒ Google::Apis::VmmigrationV1::ComputeEngineDisksTargetDefaults
ComputeEngineDisksTargetDefaults is a collection of details for creating
Persistent Disks in a target Compute Engine project.
Corresponds to the JSON property computeEngineDisksTargetDefaults
3642 3643 3644 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3642 def compute_engine_disks_target_defaults @compute_engine_disks_target_defaults end |
#compute_engine_target_defaults ⇒ Google::Apis::VmmigrationV1::ComputeEngineTargetDefaults
ComputeEngineTargetDefaults is a collection of details for creating a VM in a
target Compute Engine project.
Corresponds to the JSON property computeEngineTargetDefaults
3648 3649 3650 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3648 def compute_engine_target_defaults @compute_engine_target_defaults end |
#create_time ⇒ String
Output only. The time the migrating VM was created (this refers to this
resource and not to the time it was installed in the source).
Corresponds to the JSON property createTime
3654 3655 3656 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3654 def create_time @create_time end |
#current_sync_info ⇒ Google::Apis::VmmigrationV1::ReplicationCycle
ReplicationCycle contains information about the current replication cycle
status.
Corresponds to the JSON property currentSyncInfo
3660 3661 3662 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3660 def current_sync_info @current_sync_info end |
#cutover_forecast ⇒ Google::Apis::VmmigrationV1::CutoverForecast
CutoverForecast holds information about future CutoverJobs of a MigratingVm.
Corresponds to the JSON property cutoverForecast
3665 3666 3667 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3665 def cutover_forecast @cutover_forecast end |
#description ⇒ String
The description attached to the migrating VM by the user.
Corresponds to the JSON property description
3670 3671 3672 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3670 def description @description end |
#display_name ⇒ String
The display name attached to the MigratingVm by the user.
Corresponds to the JSON property displayName
3675 3676 3677 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3675 def display_name @display_name end |
#error ⇒ Google::Apis::VmmigrationV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
3685 3686 3687 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3685 def error @error end |
#expiration ⇒ Google::Apis::VmmigrationV1::Expiration
Expiration holds information about the expiration of a MigratingVm.
Corresponds to the JSON property expiration
3690 3691 3692 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3690 def expiration @expiration end |
#group ⇒ String
Output only. The group this migrating vm is included in, if any. The group is
represented by the full path of the appropriate Group resource.
Corresponds to the JSON property group
3696 3697 3698 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3696 def group @group end |
#labels ⇒ Hash<String,String>
The labels of the migrating VM.
Corresponds to the JSON property labels
3701 3702 3703 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3701 def labels @labels end |
#last_replication_cycle ⇒ Google::Apis::VmmigrationV1::ReplicationCycle
ReplicationCycle contains information about the current replication cycle
status.
Corresponds to the JSON property lastReplicationCycle
3707 3708 3709 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3707 def last_replication_cycle @last_replication_cycle end |
#last_sync ⇒ Google::Apis::VmmigrationV1::ReplicationSync
ReplicationSync contain information about the last replica sync to the cloud.
Corresponds to the JSON property lastSync
3712 3713 3714 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3712 def last_sync @last_sync end |
#name ⇒ String
Output only. The identifier of the MigratingVm.
Corresponds to the JSON property name
3717 3718 3719 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3717 def name @name end |
#policy ⇒ Google::Apis::VmmigrationV1::SchedulePolicy
A policy for scheduling replications.
Corresponds to the JSON property policy
3722 3723 3724 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3722 def policy @policy end |
#recent_clone_jobs ⇒ Array<Google::Apis::VmmigrationV1::CloneJob>
Output only. The recent clone jobs performed on the migrating VM. This field
holds the vm's last completed clone job and the vm's running clone job, if one
exists. Note: To have this field populated you need to explicitly request it
via the "view" parameter of the Get/List request.
Corresponds to the JSON property recentCloneJobs
3730 3731 3732 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3730 def recent_clone_jobs @recent_clone_jobs end |
#recent_cutover_jobs ⇒ Array<Google::Apis::VmmigrationV1::CutoverJob>
Output only. The recent cutover jobs performed on the migrating VM. This field
holds the vm's last completed cutover job and the vm's running cutover job, if
one exists. Note: To have this field populated you need to explicitly request
it via the "view" parameter of the Get/List request.
Corresponds to the JSON property recentCutoverJobs
3738 3739 3740 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3738 def recent_cutover_jobs @recent_cutover_jobs end |
#source_vm_id ⇒ String
The unique ID of the VM in the source. The VM's name in vSphere can be changed,
so this is not the VM's name but rather its moRef id. This id is of the form
vm-.
Corresponds to the JSON property sourceVmId
3745 3746 3747 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3745 def source_vm_id @source_vm_id end |
#state ⇒ String
Output only. State of the MigratingVm.
Corresponds to the JSON property state
3750 3751 3752 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3750 def state @state end |
#state_time ⇒ String
Output only. The last time the migrating VM state was updated.
Corresponds to the JSON property stateTime
3755 3756 3757 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3755 def state_time @state_time end |
#update_time ⇒ String
Output only. The last time the migrating VM resource was updated.
Corresponds to the JSON property updateTime
3760 3761 3762 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3760 def update_time @update_time end |
#vmware_source_vm_details ⇒ Google::Apis::VmmigrationV1::VmwareSourceVmDetails
Represent the source Vmware VM details.
Corresponds to the JSON property vmwareSourceVmDetails
3765 3766 3767 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3765 def vmware_source_vm_details @vmware_source_vm_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3772 def update!(**args) @aws_source_vm_details = args[:aws_source_vm_details] if args.key?(:aws_source_vm_details) @azure_source_vm_details = args[:azure_source_vm_details] if args.key?(:azure_source_vm_details) @compute_engine_disks_target_defaults = args[:compute_engine_disks_target_defaults] if args.key?(:compute_engine_disks_target_defaults) @compute_engine_target_defaults = args[:compute_engine_target_defaults] if args.key?(:compute_engine_target_defaults) @create_time = args[:create_time] if args.key?(:create_time) @current_sync_info = args[:current_sync_info] if args.key?(:current_sync_info) @cutover_forecast = args[:cutover_forecast] if args.key?(:cutover_forecast) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @expiration = args[:expiration] if args.key?(:expiration) @group = args[:group] if args.key?(:group) @labels = args[:labels] if args.key?(:labels) @last_replication_cycle = args[:last_replication_cycle] if args.key?(:last_replication_cycle) @last_sync = args[:last_sync] if args.key?(:last_sync) @name = args[:name] if args.key?(:name) @policy = args[:policy] if args.key?(:policy) @recent_clone_jobs = args[:recent_clone_jobs] if args.key?(:recent_clone_jobs) @recent_cutover_jobs = args[:recent_cutover_jobs] if args.key?(:recent_cutover_jobs) @source_vm_id = args[:source_vm_id] if args.key?(:source_vm_id) @state = args[:state] if args.key?(:state) @state_time = args[:state_time] if args.key?(:state_time) @update_time = args[:update_time] if args.key?(:update_time) @vmware_source_vm_details = args[:vmware_source_vm_details] if args.key?(:vmware_source_vm_details) end |