Class: Google::Apis::VmmigrationV1::MigrationError
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::MigrationError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
Represents migration resource error information that can be used with google. rpc.Status message. MigrationError is used to present the user with error information in migration operations.
Instance Attribute Summary collapse
-
#action_item ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#code ⇒ String
Output only.
-
#error_message ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#error_time ⇒ String
Output only.
-
#help_links ⇒ Array<Google::Apis::VmmigrationV1::Link>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationError
constructor
A new instance of MigrationError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationError
Returns a new instance of MigrationError.
3834 3835 3836 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_item ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property actionItem
3810 3811 3812 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3810 def action_item @action_item end |
#code ⇒ String
Output only. The error code.
Corresponds to the JSON property code
3815 3816 3817 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3815 def code @code end |
#error_message ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property errorMessage
3821 3822 3823 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3821 def @error_message end |
#error_time ⇒ String
Output only. The time the error occurred.
Corresponds to the JSON property errorTime
3826 3827 3828 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3826 def error_time @error_time end |
#help_links ⇒ Array<Google::Apis::VmmigrationV1::Link>
Output only. URL(s) pointing to additional information on handling the current
error.
Corresponds to the JSON property helpLinks
3832 3833 3834 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3832 def help_links @help_links end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3839 3840 3841 3842 3843 3844 3845 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3839 def update!(**args) @action_item = args[:action_item] if args.key?(:action_item) @code = args[:code] if args.key?(:code) @error_message = args[:error_message] if args.key?(:error_message) @error_time = args[:error_time] if args.key?(:error_time) @help_links = args[:help_links] if args.key?(:help_links) end |