Class: Google::Apis::VmmigrationV1::MigrationWarning
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::MigrationWarning
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
Represents migration resource warning information that can be used with google. rpc.Status message. MigrationWarning is used to present the user with warning information in migration operations.
Instance Attribute Summary collapse
-
#action_item ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#code ⇒ String
The warning code.
-
#help_links ⇒ Array<Google::Apis::VmmigrationV1::Link>
Output only.
-
#warning_message ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#warning_time ⇒ String
The time the warning occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationWarning
constructor
A new instance of MigrationWarning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationWarning
Returns a new instance of MigrationWarning.
3882 3883 3884 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_item ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property actionItem
3858 3859 3860 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3858 def action_item @action_item end |
#code ⇒ String
The warning code.
Corresponds to the JSON property code
3863 3864 3865 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3863 def code @code end |
#help_links ⇒ Array<Google::Apis::VmmigrationV1::Link>
Output only. URL(s) pointing to additional information on handling the current
warning.
Corresponds to the JSON property helpLinks
3869 3870 3871 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3869 def help_links @help_links end |
#warning_message ⇒ Google::Apis::VmmigrationV1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property warningMessage
3875 3876 3877 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3875 def @warning_message end |
#warning_time ⇒ String
The time the warning occurred.
Corresponds to the JSON property warningTime
3880 3881 3882 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3880 def warning_time @warning_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3887 3888 3889 3890 3891 3892 3893 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 3887 def update!(**args) @action_item = args[:action_item] if args.key?(:action_item) @code = args[:code] if args.key?(:code) @help_links = args[:help_links] if args.key?(:help_links) @warning_message = args[:warning_message] if args.key?(:warning_message) @warning_time = args[:warning_time] if args.key?(:warning_time) end |