Class: Google::Apis::VmmigrationV1::ReplicationCycle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb

Overview

ReplicationCycle contains information about the current replication cycle status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicationCycle

Returns a new instance of ReplicationCycle.



4375
4376
4377
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cycle_numberFixnum

The cycle's ordinal number. Corresponds to the JSON property cycleNumber

Returns:

  • (Fixnum)


4322
4323
4324
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4322

def cycle_number
  @cycle_number
end

#end_timeString

The time the replication cycle has ended. Corresponds to the JSON property endTime

Returns:

  • (String)


4327
4328
4329
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4327

def end_time
  @end_time
end

#errorGoogle::Apis::VmmigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4337
4338
4339
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4337

def error
  @error
end

#nameString

The identifier of the ReplicationCycle. Corresponds to the JSON property name

Returns:

  • (String)


4342
4343
4344
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4342

def name
  @name
end

#progress_percentFixnum

The current progress in percentage of this cycle. Was replaced by 'steps' field, which breaks down the cycle progression more accurately. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


4348
4349
4350
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4348

def progress_percent
  @progress_percent
end

#start_timeString

The time the replication cycle has started. Corresponds to the JSON property startTime

Returns:

  • (String)


4353
4354
4355
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4353

def start_time
  @start_time
end

#stateString

State of the ReplicationCycle. Corresponds to the JSON property state

Returns:

  • (String)


4358
4359
4360
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4358

def state
  @state
end

#stepsArray<Google::Apis::VmmigrationV1::CycleStep>

The cycle's steps list representing its progress. Corresponds to the JSON property steps



4363
4364
4365
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4363

def steps
  @steps
end

#total_pause_durationString

The accumulated duration the replication cycle was paused. Corresponds to the JSON property totalPauseDuration

Returns:

  • (String)


4368
4369
4370
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4368

def total_pause_duration
  @total_pause_duration
end

#warningsArray<Google::Apis::VmmigrationV1::MigrationWarning>

Output only. Warnings that occurred during the cycle. Corresponds to the JSON property warnings



4373
4374
4375
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4373

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4380

def update!(**args)
  @cycle_number = args[:cycle_number] if args.key?(:cycle_number)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
  @total_pause_duration = args[:total_pause_duration] if args.key?(:total_pause_duration)
  @warnings = args[:warnings] if args.key?(:warnings)
end