Class: Google::Apis::VmmigrationV1::Source
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::Source
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
Source message describes a specific vm migration Source resource. It contains the source environment information.
Instance Attribute Summary collapse
-
#aws ⇒ Google::Apis::VmmigrationV1::AwsSourceDetails
AwsSourceDetails message describes a specific source details for the AWS source type.
-
#azure ⇒ Google::Apis::VmmigrationV1::AzureSourceDetails
AzureSourceDetails message describes a specific source details for the Azure source type.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description of the source.
-
#encryption ⇒ Google::Apis::VmmigrationV1::Encryption
Encryption message describes the details of the applied encryption.
-
#labels ⇒ Hash<String,String>
The labels of the source.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vmware ⇒ Google::Apis::VmmigrationV1::VmwareSourceDetails
VmwareSourceDetails message describes a specific source details for the vmware source type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
4641 4642 4643 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aws ⇒ Google::Apis::VmmigrationV1::AwsSourceDetails
AwsSourceDetails message describes a specific source details for the AWS
source type.
Corresponds to the JSON property aws
4597 4598 4599 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4597 def aws @aws end |
#azure ⇒ Google::Apis::VmmigrationV1::AzureSourceDetails
AzureSourceDetails message describes a specific source details for the Azure
source type.
Corresponds to the JSON property azure
4603 4604 4605 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4603 def azure @azure end |
#create_time ⇒ String
Output only. The create time timestamp.
Corresponds to the JSON property createTime
4608 4609 4610 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4608 def create_time @create_time end |
#description ⇒ String
User-provided description of the source.
Corresponds to the JSON property description
4613 4614 4615 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4613 def description @description end |
#encryption ⇒ Google::Apis::VmmigrationV1::Encryption
Encryption message describes the details of the applied encryption.
Corresponds to the JSON property encryption
4618 4619 4620 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4618 def encryption @encryption end |
#labels ⇒ Hash<String,String>
The labels of the source.
Corresponds to the JSON property labels
4623 4624 4625 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4623 def labels @labels end |
#name ⇒ String
Output only. The Source name.
Corresponds to the JSON property name
4628 4629 4630 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4628 def name @name end |
#update_time ⇒ String
Output only. The update time timestamp.
Corresponds to the JSON property updateTime
4633 4634 4635 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4633 def update_time @update_time end |
#vmware ⇒ Google::Apis::VmmigrationV1::VmwareSourceDetails
VmwareSourceDetails message describes a specific source details for the vmware
source type.
Corresponds to the JSON property vmware
4639 4640 4641 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4639 def vmware @vmware end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4646 def update!(**args) @aws = args[:aws] if args.key?(:aws) @azure = args[:azure] if args.key?(:azure) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @encryption = args[:encryption] if args.key?(:encryption) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @vmware = args[:vmware] if args.key?(:vmware) end |