Class: Google::Apis::VmmigrationV1::TargetProject
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::TargetProject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
TargetProject message represents a target Compute Engine project for a migration or a clone.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The target project's description.
-
#name ⇒ String
Output only.
-
#project ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetProject
constructor
A new instance of TargetProject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetProject
Returns a new instance of TargetProject.
4786 4787 4788 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time this target project resource was created (not related to
when the Compute Engine project it points to was created).
Corresponds to the JSON property createTime
4764 4765 4766 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4764 def create_time @create_time end |
#description ⇒ String
The target project's description.
Corresponds to the JSON property description
4769 4770 4771 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4769 def description @description end |
#name ⇒ String
Output only. The name of the target project.
Corresponds to the JSON property name
4774 4775 4776 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4774 def name @name end |
#project ⇒ String
Required. The target project ID (number) or project name.
Corresponds to the JSON property project
4779 4780 4781 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4779 def project @project end |
#update_time ⇒ String
Output only. The last time the target project resource was updated.
Corresponds to the JSON property updateTime
4784 4785 4786 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4784 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4791 4792 4793 4794 4795 4796 4797 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4791 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @project = args[:project] if args.key?(:project) @update_time = args[:update_time] if args.key?(:update_time) end |