Class: Google::Apis::VmmigrationV1::UtilizationReport
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1::UtilizationReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1/classes.rb,
lib/google/apis/vmmigration_v1/representations.rb,
lib/google/apis/vmmigration_v1/representations.rb
Overview
Utilization report details the utilization (CPU, memory, etc.) of selected source VMs.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The report display name, as assigned by the user.
-
#error ⇒ Google::Apis::VmmigrationV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#frame_end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_time ⇒ String
Output only.
-
#time_frame ⇒ String
Time frame of the report.
-
#vm_count ⇒ Fixnum
Output only.
-
#vms ⇒ Array<Google::Apis::VmmigrationV1::VmUtilizationInfo>
List of utilization information per VM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UtilizationReport
constructor
A new instance of UtilizationReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UtilizationReport
Returns a new instance of UtilizationReport.
4948 4949 4950 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the report was created (this refers to the time of the
request, not the time the report creation completed).
Corresponds to the JSON property createTime
4891 4892 4893 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4891 def create_time @create_time end |
#display_name ⇒ String
The report display name, as assigned by the user.
Corresponds to the JSON property displayName
4896 4897 4898 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4896 def display_name @display_name end |
#error ⇒ Google::Apis::VmmigrationV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4906 4907 4908 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4906 def error @error end |
#frame_end_time ⇒ String
Output only. The point in time when the time frame ends. Notice that the time
frame is counted backwards. For instance if the "frame_end_time" value is 2021/
01/20 and the time frame is WEEK then the report covers the week between 2021/
01/20 and 2021/01/14.
Corresponds to the JSON property frameEndTime
4914 4915 4916 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4914 def frame_end_time @frame_end_time end |
#name ⇒ String
Output only. The report unique name.
Corresponds to the JSON property name
4919 4920 4921 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4919 def name @name end |
#state ⇒ String
Output only. Current state of the report.
Corresponds to the JSON property state
4924 4925 4926 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4924 def state @state end |
#state_time ⇒ String
Output only. The time the state was last set.
Corresponds to the JSON property stateTime
4929 4930 4931 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4929 def state_time @state_time end |
#time_frame ⇒ String
Time frame of the report.
Corresponds to the JSON property timeFrame
4934 4935 4936 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4934 def time_frame @time_frame end |
#vm_count ⇒ Fixnum
Output only. Total number of VMs included in the report.
Corresponds to the JSON property vmCount
4939 4940 4941 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4939 def vm_count @vm_count end |
#vms ⇒ Array<Google::Apis::VmmigrationV1::VmUtilizationInfo>
List of utilization information per VM. When sent as part of the request, the "
vm_id" field is used in order to specify which VMs to include in the report.
In that case all other fields are ignored.
Corresponds to the JSON property vms
4946 4947 4948 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4946 def vms @vms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 |
# File 'lib/google/apis/vmmigration_v1/classes.rb', line 4953 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @frame_end_time = args[:frame_end_time] if args.key?(:frame_end_time) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_time = args[:state_time] if args.key?(:state_time) @time_frame = args[:time_frame] if args.key?(:time_frame) @vm_count = args[:vm_count] if args.key?(:vm_count) @vms = args[:vms] if args.key?(:vms) end |